//
// A sample which uses the fractal library
//
//                              by Sebastian Mihai, 2013
//

// onload method
function smOnload() {

	// point the fractal generator at the proper DOM element
	var fractal = new Fractal( "smCanvas" );
	
	// we'll generate up to this depth
	fractal.SetMaxDepth( 800 );

	var cx = fractal.Width() / 2;
	var cy = fractal.Height() / 2;
	
	// our first node will be in the centre of the canvas
	
	fractal.Queue().Push( new QueueItem( cx - 5, cy - 5, 0 ) );
	
	var rotate = function( 
		theFractal, 
		x, 
		y,
		centreX,
		centreY,
		angle, 
		depth 
		) {
		// rotate around centre and increase radius slightly
		
		var cosAngle = Math.cos( angle );
		var sinAngle = Math.sin( angle );
		
		var xWRTCentre = x - centreX;
		var yWRTCentre = y - centreY;
		
		var spiralFactor = 1.0 + angle/12;
		
		// rotate and spiral outward
		var newXWRTCentre = spiralFactor * ( xWRTCentre * cosAngle - yWRTCentre * sinAngle );
		var newYWRTCentre = spiralFactor * ( xWRTCentre * sinAngle + yWRTCentre * cosAngle );
		
		var newX = newXWRTCentre + centreX;
		var newY = newYWRTCentre + centreY;
		
		return new QueueItem( newX, newY, depth+1 );
	}
	
	// this function will be called by the fractal generator for each node
	var delegate = function( theFractal, theQueue, node, depth ) {
		
		var x = node.X();
		var y = node.Y();
		
		// draw a circle at [x,y]
		theFractal.DrawCircle( x, y, depth % 4 );
		
		var centreX = theFractal.Width() / 2;
		var centreY = theFractal.Height() / 2;
		
		var next = rotate( theFractal, x, y, centreX, centreY, Math.PI / 48, depth );

		// queue up the next node
		theQueue.Push( next );
		
		if( depth % 100 == 0 ) {
			var next2 = rotate( theFractal, next.Y()+1, next.X(), y, x, -Math.PI / 33, 0 );
			theQueue.Push( next2 );
		}

	}

	// tell fractal generator about our delegate
	fractal.SetDelegate( delegate );
	
	// this fractal looks better in black and white
	fractal.UseGrayscale();
	
	// render fractal in an progressive, animated fashion
	// ( for a direct rendering, use fractal.Render() )
	//fractal.RenderProgressively();
	fractal.Render();
}
